{-# OPTIONS_GHC -Wall #-}
{-# OPTIONS_GHC -fno-warn-unused-imports #-}
{-# OPTIONS_GHC -fno-warn-orphans #-}
{-# Language ForeignFunctionInterface #-}
{-# Language FlexibleInstances #-}
{-# Language MultiParamTypeClasses #-}

module Casadi.Control.Classes.DpleSolver
       (
         DpleSolver,
         DpleSolverClass(..),
         dpleSolver__0,
         dpleSolver__1,
         dpleSolver_clone,
         dpleSolver_doc,
         dpleSolver_loadPlugin,
         dpleSolver_printStats,
       ) where


import Prelude hiding ( Functor )

import Data.Vector ( Vector )
import Foreign.C.Types
import Foreign.Marshal ( new, free )
import Foreign.Storable ( peek )
import Foreign.Ptr ( Ptr, nullPtr )
import Foreign.ForeignPtr ( newForeignPtr )
import System.IO.Unsafe ( unsafePerformIO ) -- for show instances

import Casadi.Internal.CToolsInstances ( )
import Casadi.Internal.FormatException ( formatException )
import Casadi.Internal.MarshalTypes ( StdVec, StdString) -- StdPair StdOstream'
import Casadi.Internal.Marshal ( Marshal(..), withMarshal )
import Casadi.Internal.WrapReturn ( WrapReturn(..) )
import Casadi.Control.Data
import Casadi.Control.Enums
import Casadi.Core.Data

-- direct wrapper
foreign import ccall unsafe "casadi__DpleSolver__CONSTRUCTOR__0" c_casadi__DpleSolver__CONSTRUCTOR__0
  :: Ptr (Ptr StdString) -> Ptr StdString -> Ptr (StdVec (Ptr Sparsity')) -> Ptr (StdVec (Ptr Sparsity')) -> IO (Ptr DpleSolver')
casadi__DpleSolver__CONSTRUCTOR__0
  :: String -> Vector Sparsity -> Vector Sparsity -> IO DpleSolver
casadi__DpleSolver__CONSTRUCTOR__0 x0 x1 x2 =
  withMarshal x0 $ \x0' ->
  withMarshal x1 $ \x1' ->
  withMarshal x2 $ \x2' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__DpleSolver__CONSTRUCTOR__0 errStrPtrP x0' x1' x2'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
dpleSolver__0 :: String -> Vector Sparsity -> Vector Sparsity -> IO DpleSolver
dpleSolver__0 = casadi__DpleSolver__CONSTRUCTOR__0


-- direct wrapper
foreign import ccall unsafe "casadi__DpleSolver__CONSTRUCTOR__1" c_casadi__DpleSolver__CONSTRUCTOR__1
  :: Ptr (Ptr StdString) -> IO (Ptr DpleSolver')
casadi__DpleSolver__CONSTRUCTOR__1
  :: IO DpleSolver
casadi__DpleSolver__CONSTRUCTOR__1  =

  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__DpleSolver__CONSTRUCTOR__1 errStrPtrP 
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
dpleSolver__1 :: IO DpleSolver
dpleSolver__1 = casadi__DpleSolver__CONSTRUCTOR__1


-- direct wrapper
foreign import ccall unsafe "casadi__DpleSolver__clone" c_casadi__DpleSolver__clone
  :: Ptr (Ptr StdString) -> Ptr DpleSolver' -> IO (Ptr DpleSolver')
casadi__DpleSolver__clone
  :: DpleSolver -> IO DpleSolver
casadi__DpleSolver__clone x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__DpleSolver__clone errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
dpleSolver_clone :: DpleSolverClass a => a -> IO DpleSolver
dpleSolver_clone x = casadi__DpleSolver__clone (castDpleSolver x)


-- direct wrapper
foreign import ccall unsafe "casadi__DpleSolver__doc" c_casadi__DpleSolver__doc
  :: Ptr (Ptr StdString) -> Ptr StdString -> IO (Ptr StdString)
casadi__DpleSolver__doc
  :: String -> IO String
casadi__DpleSolver__doc x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__DpleSolver__doc errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
dpleSolver_doc :: String -> IO String
dpleSolver_doc = casadi__DpleSolver__doc


-- direct wrapper
foreign import ccall unsafe "casadi__DpleSolver__loadPlugin" c_casadi__DpleSolver__loadPlugin
  :: Ptr (Ptr StdString) -> Ptr StdString -> IO ()
casadi__DpleSolver__loadPlugin
  :: String -> IO ()
casadi__DpleSolver__loadPlugin x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__DpleSolver__loadPlugin errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
dpleSolver_loadPlugin :: String -> IO ()
dpleSolver_loadPlugin = casadi__DpleSolver__loadPlugin


-- direct wrapper
foreign import ccall unsafe "casadi__DpleSolver__printStats" c_casadi__DpleSolver__printStats
  :: Ptr (Ptr StdString) -> Ptr DpleSolver' -> IO ()
casadi__DpleSolver__printStats
  :: DpleSolver -> IO ()
casadi__DpleSolver__printStats x0 =
  withMarshal x0 $ \x0' ->
  do
    errStrPtrP <- new nullPtr
    ret <- c_casadi__DpleSolver__printStats errStrPtrP x0'
    errStrPtr <- peek errStrPtrP
    free errStrPtrP
    if errStrPtr == nullPtr then wrapReturn ret else wrapReturn errStrPtr >>= (error . formatException)


-- classy wrapper
dpleSolver_printStats :: DpleSolverClass a => a -> IO ()
dpleSolver_printStats x = casadi__DpleSolver__printStats (castDpleSolver x)

